
# Binary search example

This is a simple visualization of a binary search.

## Try out

```bash
git clone git@github.com:breuleux/giving.git
cd examples/live_bisect
pip install -r requirements.txt
python main.py
```

## Image

![bisect](https://github.com/breuleux/giving/raw/media/media/bisect.gif)
